
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareSlash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-slash'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'line': {'x1': '9', 'x2': '15', 'y1': '15', 'y2': '9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
