
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileXCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-x-corner'], 'items': [{'path': {'d': 'M11 22H6a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v5'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm15 17 5 5'}}, {'path': {'d': 'm20 17-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
