
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-x'], 'items': [{'path': {'d': 'M2 21a8 8 0 0 1 11.873-7'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}, {'path': {'d': 'm17 17 5 5'}}, {'path': {'d': 'm22 17-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
