
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Archive(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-archive'], 'items': [{'rect': {'width': '20', 'height': '5', 'x': '2', 'y': '3', 'rx': '1'}}, {'path': {'d': 'M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8'}}, {'path': {'d': 'M10 12h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
