
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-arrow-down'], 'items': [{'path': {'d': 'm14 18 4 4 4-4'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M18 14v8'}}, {'path': {'d': 'M21 11.354V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7.343'}}, {'path': {'d': 'M3 10h18'}}, {'path': {'d': 'M8 2v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
